import { Prop, Schema, SchemaFactory } from '@nestjs/mongoose';
import { Document } from 'mongoose';
import { Address } from '../../structures/schemas/address.schema';

export class Structure {
  @Prop()
  nom: string;

  @Prop()
  adresse: Address;

  @Prop({ required: false })
  zoneCTM?: string;

  @Prop({ required: false })
  distance?: number;
}

export class Type {
  @Prop({
    type: String,
    enum: ['accès matériel', 'achat matériel', 'démarche en ligne', 'compétences'],
  })
  typeOrientation: 'accès matériel' | 'achat matériel' | 'démarche en ligne' | 'compétences';

  @Prop([String])
  filtres: string[];

  @Prop({
    type: String,
    enum: ['rdv en ligne', 'médiation', 'trouver une structure'],
  })
  typeAccompagnement: 'rdv en ligne' | 'médiation' | 'trouver une structure';
}

export type OrientationIndicatorDocument = OrientationIndicator & Document;

@Schema()
export class OrientationIndicator {
  @Prop({ type: Object })
  origin: {
    nom: string;
    prescripteur: string;
    adresse: Address;
  };

  @Prop([Structure])
  target: Structure[];

  @Prop(Type)
  type: Type;

  @Prop({ required: true })
  connected: boolean;

  @Prop({ required: true })
  completed: boolean;

  @Prop({ required: true })
  progress: number;

  @Prop({ type: Date, default: Date.now })
  createdAt: Date;
}

export const OrientationIndicatorSchema = SchemaFactory.createForClass(OrientationIndicator);
