import { Db } from 'mongodb';
import { StructureTypeDocument } from '../../structures/structure-type/structure-type.schema';
import { getDb } from '../migrations-utils/db';

export const up = async () => {
  const db: Db = await getDb();
  const cursor = db.collection('structuretype').find({});
  let document;
  const documents = [];
  // List documents to process
  while ((document = await cursor.next())) {
    documents.push(document);
  }

  await Promise.all(
    documents.map(async (documentToUpdate) => {
      await insert(db, documentToUpdate);
      return db.collection('structuretype').deleteOne({ _id: documentToUpdate._id });
    })
  );
  db.collection('structuretype').insertOne({ category: 'Publique', value: 'autre', selectable: false });

  const cursorStructure = db.collection('structures').find({});
  let structure;
  while ((structure = await cursorStructure.next())) {
    if (structure.structureType) {
      const structureType = await db
        .collection('structuretype')
        .findOne<StructureTypeDocument>({ value: structure.structureType });
      await db
        .collection('structures')
        .updateOne({ _id: structure._id }, { $set: { structureType: structureType ? structureType._id : null } });
    }
  }

  console.log('Update done : structure type are now referenced by their ObjectId');
};

export const down = async () => {
  const db: Db = await getDb();

  const cursorStructure = db.collection('structures').find({});
  let structure;
  while ((structure = await cursorStructure.next())) {
    if (structure.structureType) {
      const structureType = await db
        .collection('structuretype')
        .findOne<StructureTypeDocument>({ _id: structure.structureType });
      await db
        .collection('structures')
        .updateOne({ _id: structure._id }, { $set: { structureType: structureType.value } });
    }
  }

  const cursor = db.collection('structuretype').find({});
  let document;
  const documents = [];

  // List documents to process
  while ((document = await cursor.next())) {
    documents.push(document);
  }

  await Promise.all(
    documents.map(async (documentToUpdate) => {
      if (documentToUpdate.value !== 'autre') {
        await db
          .collection('structuretype')
          .updateOne(
            { name: documentToUpdate.category },
            { $push: { values: documentToUpdate.value } },
            { upsert: true }
          );
      }
      await db.collection('structuretype').deleteOne({ _id: documentToUpdate._id });
    })
  );

  console.log('Downgrade done : structure type are now referenced by their value');
};

const insert = async (db: Db, document) => {
  return Promise.all(
    document.values.map(async (value) => {
      return db.collection('structuretype').insertOne({ category: document.name, value: value, selectable: true });
    })
  );
};
