import { Db } from 'mongodb';
import { getDb } from '../migrations-utils/db';

export const up = async () => {
  const db: Db = await getDb();

  await db.collection('categories').updateOne(
    { id: 'onlineProcedures' },
    {
      $pull: { modules: { id: 'cpam' } },
    }
  );

  await db.collection('categories').updateOne(
    { id: 'onlineProcedures', 'modules.id': 'health' },
    {
      $set: { 'modules.$.name': 'Santé (Ameli, CPAM...)' },
    }
  );

  // Iterate through cpam structures, remove cpam from onlineProcedures and add health if not already present
  const cursor = db.collection('structures').find({ 'categories.onlineProcedures': 'cpam' });
  let cpamStructure;
  while ((cpamStructure = await cursor.next())) {
    const updatedOnlineProcedures = cpamStructure.categories.onlineProcedures.filter((item) => item !== 'cpam');

    if (!updatedOnlineProcedures.includes('health')) {
      updatedOnlineProcedures.push('health');
    }

    await db
      .collection('structures')
      .updateOne({ _id: cpamStructure._id }, { $set: { 'categories.onlineProcedures': updatedOnlineProcedures } });
  }
  console.log('Updated : replace cpam online procedure with health');
};

export const down = async () => {
  const db: Db = await getDb();

  await db.collection('categories').updateOne(
    { id: 'onlineProcedures' },
    {
      $push: { modules: { id: 'cpam', name: 'CPAM' } },
    }
  );

  await db.collection('categories').updateOne(
    { id: 'onlineProcedures', 'modules.id': 'health' },
    {
      $set: { 'modules.$.name': 'Santé (Ameli...)' },
    }
  );
  console.log('Downgraded : added cpam online procedure and renamed health');
};
