import { sanitize } from './utils';

describe('sanitize', () => {
  it('should do nothing if the string is already sanitized', () => {
    expect(sanitize('abcdefghijklmnopqrstuvwxyz1234567890')).toBe('abcdefghijklmnopqrstuvwxyz1234567890');
  });

  it('should remove trailing spaces', () => {
    expect(sanitize(' abc ')).toBe('abc');
  });

  it('should be lowercase', () => {
    expect(sanitize('ABC')).toBe('abc');
  });

  it('should remove accents', () => {
    expect(sanitize('àèìòùÀÈÌÒÙáéíóúýÁÉÍÓÚÝâêîôûÂÊÎÔÛãñõÃÑÕäëïöüÿÄËÏÖÜŸçÇÅå')).toBe(
      'aeiouaeiouaeiouyaeiouyaeiouaeiouanoanoaeiouyaeiouyccaa'
    );
  });

  it('should replace " - " by "-"', () => {
    expect(sanitize('Mairie - Lyon 8')).toBe('mairie-lyon-8');
  });

  it('should replace " / " by "-"', () => {
    expect(sanitize('Mairie / Lyon 8')).toBe('mairie-lyon-8');
  });

  it('should replace spaces by "-"', () => {
    expect(sanitize('a b c d')).toBe('a-b-c-d');
  });

  it('should remove parenthesis', () => {
    expect(sanitize('Mairie (Lyon 8)')).toBe('mairie-lyon-8');
  });

  it('should remove all non-alphanumeric characters', () => {
    expect(sanitize('@%#$.!?;:+=[]{}~\'"')).toBe('');
  });
});
