import { HttpModule } from '@nestjs/axios';
import { HttpStatus } from '@nestjs/common';
import { Test } from '@nestjs/testing';
import { MailerModule } from '../mailer/mailer.module';
import { TempUserController } from './temp-user.controller';
import { TempUserService } from './temp-user.service';

describe('TempUserService', () => {
  let tempUserController: TempUserController;

  const mockTempUserService = {
    findById: jest.fn(),
    findAll: jest.fn(),
  };

  beforeEach(async () => {
    const module = await Test.createTestingModule({
      imports: [HttpModule, MailerModule],
      providers: [{ provide: TempUserService, useValue: mockTempUserService }],
      controllers: [TempUserController],
    }).compile();

    tempUserController = module.get<TempUserController>(TempUserController);
  });

  it('should be defined', () => {
    expect(tempUserController).toBeDefined();
  });

  describe('findAll', () => {
    it('should get all temporary users', async () => {
      await tempUserController.findAll();
      expect(mockTempUserService.findAll).toHaveBeenCalled();
    });
  });

  describe('getTempUser', () => {
    it('should get a temporary user by ID', async () => {
      mockTempUserService.findById.mockResolvedValueOnce('something');
      await tempUserController.getTempUser('Azerty651');
      expect(mockTempUserService.findById).toHaveBeenCalledWith('Azerty651');
    });
    it('should throw error in case of no users', async () => {
      mockTempUserService.findById.mockReturnValueOnce(null);
      try {
        await tempUserController.getTempUser('Azerty651');
        expect(true).toBe(false);
      } catch (e) {
        expect(e.message).toEqual('Temp user does not exist');
        expect(e.status).toEqual(HttpStatus.BAD_REQUEST);
      }
    });
  });
});
