import { Test } from '@nestjs/testing';
import { Types } from 'mongoose';
import { ConfigurationModule } from '../../configuration/configuration.module';
import { SearchModule } from '../../search/search.module';
import { EmployerDocument } from '../schemas/employer.schema';
import { EmployerSearchService } from './employer-search.service';

const employers = [
  {
    _id: new Types.ObjectId('6231aefe76598527c8d0b5ba'),
    name: 'Metro',
    validated: true,
  } as EmployerDocument,
  {
    _id: new Types.ObjectId('6231aefe76598527c8d0b5bb'),
    name: 'Sopra',
    validated: true,
  } as EmployerDocument,
  {
    _id: new Types.ObjectId('6231aefe76598527c8d0b5bd'),
    name: 'CGI',
    validated: true,
  } as EmployerDocument,
  {
    _id: new Types.ObjectId('6231aefe76598527c8d0b5be'),
    name: 'Decathlon',
    validated: true,
  } as EmployerDocument,
  {
    _id: new Types.ObjectId('6231aefe76598527c8d0b5bf'),
    name: 'Apollo',
    validated: true,
  } as EmployerDocument,
];
describe('EmployerSearchService Search cases', () => {
  let employerSearchService: EmployerSearchService;

  beforeEach(async () => {
    const module = await Test.createTestingModule({
      imports: [SearchModule, ConfigurationModule],
      providers: [EmployerSearchService],
    }).compile();

    employerSearchService = module.get<EmployerSearchService>(EmployerSearchService);
    employerSearchService['index'] = 'employer-unit-test';
    // Init test cases
    await employerSearchService.dropIndex();
    await employerSearchService.createEmployerIndex();
    await Promise.all(employers.map((employer) => employerSearchService.indexEmployer(employer)));

    // wait for the new structures to be indexed before search
    await employerSearchService.refreshIndexStructure();
    await new Promise((r) => setTimeout(r, 2000));
  }, 10000);

  it('should be defined', async () => {
    expect(employerSearchService).toBeDefined();
  });

  it('should find Metro', async () => {
    const res = await employerSearchService.search('Metro');
    expect(res[0].name).toBe('Metro');
    expect(res.length).toBe(1);
  });
  it('should find Sopra', async () => {
    const res = await employerSearchService.search('Sopra');
    expect(res[0].name).toBe('Sopra');
    expect(res.length).toBe(1);
  });

  it('should index structures', async () => {
    const res = await Promise.all(employers.map((employer) => employerSearchService.indexEmployer(employer)));

    expect(res).toBeTruthy();
    expect(res.length).toBe(5);
  });

  it('should update index', async () => {
    const resCaf = await employerSearchService.search('Metro');
    const res = await employerSearchService.update(
      resCaf[0] as EmployerDocument,
      new Types.ObjectId('6231aefe76598527c8d0b5ba').toHexString()
    );
    expect(res).toBeTruthy();
  });
  it('should delete index', async () => {
    const resCaf = await employerSearchService.search('Metro');
    const res = await employerSearchService.deleteIndex(
      resCaf[0] as EmployerDocument,
      new Types.ObjectId('6231aefe76598527c8d0b5ba').toHexString()
    );
    expect(res).toBeTruthy();
  });
});
