import { EspaceCoopCNFS } from '../../../src/espaceCoop/schemas/espaceCoopCNFS.schema';
import { Permanence } from '../../../src/espaceCoop/interfaces/permanence.interface';
// Results from https://api.conseiller-numerique.gouv.fr/permanences
export const espaceCoopPermanencesMockData: Permanence[] = [
  // Structure with 1 CNFS (email + phone number)
  {
    id: '6391e932f0518a05c2cf50f5',
    nom: 'MISSION LOCALE DE LYON',
    services:
      'Prendre en main un smartphone ou une tablette;Prendre en main un ordinateur;Utiliser le numérique au quotidien;Approfondir ma culture numérique',
    pivot: '37846987800037',
    commune: 'LYON',
    code_postal: '69001',
    adresse: '2 Rue des Pierres Plantées',
    latitude: 45.773969,
    longitude: 4.832108,
    telephone: '+33767512257',
    courriel: 'mlpentes@mllyon.org',
    conditions_acces: 'Gratuit : Je peux accéder gratuitement au lieu et à ses services',
    labels_nationaux: 'CNFS',
    horaires: 'Mo-Fr 09:00-12:30,13:30-17:00',
    source: 'conseiller-numerique',
    date_maj: '2023-03-20',
    structureId: '606c6c34250d66297ef85027',
    structureNom: "MAISON METROPOLITAINE D'INSERTION POUR L'EMPLOI GIP",
    aidants: [
      {
        aidantId: '60828cc84f47999865ada92e',
        nom: 'Sharif Adeoti',
        courriel: 'sadeoti@lyonmetropole-mmie.fr',
        telephone: '+33766424152',
      },
    ],
  },
  // Structure with 1 CNFS (only email)
  {
    id: '638266bcf7aaa606f26404cb',
    nom: 'ASS MISSION LOCALE DE VAULX EN VELIN',
    services:
      'Prendre en main un smartphone ou une tablette;Prendre en main un ordinateur;Utiliser le numérique au quotidien;Approfondir ma culture numérique',
    pivot: '32866815700014',
    commune: 'VAULX-EN-VELIN',
    code_postal: '69120',
    adresse: 'Place de la Nation',
    latitude: 45.778049,
    longitude: 4.921221,
    telephone: '+33472049414',
    courriel: 'contact@mlvaulx.org',
    site_web: 'https://mlvaulxenvelin.org/',
    conditions_acces: 'Gratuit : Je peux accéder gratuitement au lieu et à ses services',
    labels_nationaux: 'CNFS',
    horaires: 'Mo-Fr 08:45-12:45,13:30-17:30',
    source: 'conseiller-numerique',
    date_maj: '2022-11-26',
    structureId: '60813b1d4f47999865a21876',
    structureNom: 'ASS MISSION LOCALE DE VAULX EN VELIN',
    aidants: [{ aidantId: '61792388838083d33903eed1', nom: 'Anthony Tissot', courriel: 'anthony.tissot@mlvaulx.org' }],
  },
  // Structure with 1 CNFS (no email and no phone number)
  {
    id: '63eb85e4561e1c06f3aef839',
    nom: 'Croix Rouge Française',
    services:
      'Prendre en main un smartphone ou une tablette;Prendre en main un ordinateur;Utiliser le numérique au quotidien;Approfondir ma culture numérique',
    pivot: '00000000000000',
    commune: 'VAULX-EN-VELIN',
    code_postal: '69120',
    adresse: 'Rue Alexandre Dumas',
    latitude: 45.753581,
    longitude: 4.92724,
    conditions_acces: 'Gratuit : Je peux accéder gratuitement au lieu et à ses services',
    labels_nationaux: 'CNFS',
    horaires: 'Tu-Th 09:00-12:30,14:00-17:00; Mo 14:00-17:00; Fr 09:00-12:30,14:00-16:00',
    source: 'conseiller-numerique',
    date_maj: '2023-02-14',
    structureId: '60a6a3b5838083d339247177',
    structureNom: 'CROIX ROUGE FRANCAISE',
    aidants: [{ aidantId: '609ad488838083d339b0b40b', nom: 'Colette Jacquot' }],
  },
  // Structure with 2 CNFS (the second one also works in first structure)
  {
    id: '62ac6f118255a806e299d706',
    nom: 'COMMUNE DE SAINT FONS',
    services:
      'Prendre en main un smartphone ou une tablette;Prendre en main un ordinateur;Utiliser le numérique au quotidien;Approfondir ma culture numérique',
    pivot: '21690199100010',
    commune: 'SAINT-FONS',
    code_postal: '69190',
    adresse: 'Place Roger Salengro',
    latitude: 45.708789,
    longitude: 4.852529,
    telephone: '+33478709698',
    courriel: 'accueil@saint-fons.fr',
    site_web: 'https://www.saint-fons.fr',
    conditions_acces: 'Gratuit : Je peux accéder gratuitement au lieu et à ses services',
    labels_nationaux: 'CNFS',
    horaires: 'Tu-Fr 08:30-12:00,13:30-17:30; Mo 13:30-17:30',
    source: 'conseiller-numerique',
    date_maj: '2022-06-24',
    structureId: '606c6c34250d66297ef85027',
    structureNom: "MAISON METROPOLITAINE D'INSERTION POUR L'EMPLOI GIP",
    aidants: [
      {
        aidantId: '60c0bbcf838083d339436e54',
        nom: 'Aurore Viel',
        courriel: 'aviel@lyonmetropole-mmie.fr',
        telephone: '+33781586957',
      },
      {
        aidantId: '60828cc84f47999865ada92e',
        nom: 'Sharif Adeoti',
        courriel: 'sadeoti@lyonmetropole-mmie.fr',
        telephone: '+33766424152',
      },
    ],
  },
];

export const espaceCoopCNFSMockData: EspaceCoopCNFS[] = [
  {
    name: 'Sharif Adeoti',
    email: 'sadeoti@lyonmetropole-mmie.fr',
    phone: '+33766424152',
    employer: "MAISON METROPOLITAINE D'INSERTION POUR L'EMPLOI GIP",
    structures: ['MISSION LOCALE DE LYON', 'COMMUNE DE SAINT FONS'],
    hasAccount: true,
  },
  {
    name: 'Anthony Tissot',
    email: 'anthony.tissot@mlvaulx.org',
    phone: null,
    employer: 'ASS MISSION LOCALE DE VAULX EN VELIN',
    structures: ['ASS MISSION LOCALE DE VAULX EN VELIN'],
    hasAccount: false,
  },
  {
    name: 'Colette Jacquot',
    email: null,
    phone: null,
    employer: 'CROIX ROUGE FRANCAISE',
    structures: ['Croix Rouge Française'],
    hasAccount: false,
  },
  {
    name: 'Aurore Viel',
    email: 'aviel@lyonmetropole-mmie.fr',
    phone: '+33781586957',
    employer: "MAISON METROPOLITAINE D'INSERTION POUR L'EMPLOI GIP",
    structures: ['COMMUNE DE SAINT FONS'],
    hasAccount: false,
  },
];
