import { HttpException, HttpStatus } from '@nestjs/common';
import { Types, isValidObjectId } from 'mongoose';
import { PendingStructureDto } from '../../../src/admin/dto/pending-structure.dto';
import { LoginDto } from '../../../src/auth/login-dto';
import { PersonalOffer, PersonalOfferDocument } from '../../../src/personal-offers/schemas/personal-offer.schema';
import { Structure } from '../../../src/structures/schemas/structure.schema';
import { IUser } from '../../../src/users/interfaces/user.interface';
import { User } from '../../../src/users/schemas/user.schema';
import { personalOffersDataMock } from '../data/personalOffers.mock.data';

export class UsersServiceMock {
  findOne(mail: string, passwordQuery?: boolean) {
    if (mail === 'pauline.dupont@mii.com') {
      return {
        _id: 'tsfsf6296',
        validationToken:
          'cf1c74c22cedb6b575945098db42d2f493fb759c9142c6aff7980f252886f36ee086574ee99a06bc99119079257116c959c8ec870949cebdef2b293666dbca42',
        emailVerified: true,
        email: 'pauline.dupont@mii.com',
        password: '$2a$12$vLQjJ9zAWyUwiFLeQDa6w.XzrlgPBhw.2GWrjog/yuEjIaZnQwmZu',
        role: 0,
        name: 'DUPONT',
        surname: 'Pauline',
        personalOffers: [],
      };
    }
    if (mail === 'jacques.dupont@mii.com') {
      if (passwordQuery) {
        return {
          _id: 'tsfsf6296',
          validationToken:
            'cf1c74c22cedb6b575945098db42d2f493fb759c9142c6aff7980f252886f36ee086574ee99a06bc99119079257116c959c8ec870949cebdef2b293666dbca42',
          emailVerified: false,
          email: 'jacques.dupont@mii.com',
          password: '$2a$12$vLQjJ9zAWyUwiFLeQDa6w.XzrlgPBhw.2GWrjog/yuEjIaZnQwmZu',
          role: 0,
          personalOffers: [],
        };
      }
      return {
        _id: 'tsfsf6296',
        validationToken:
          'cf1c74c22cedb6b575945098db42d2f493fb759c9142c6aff7980f252886f36ee086574ee99a06bc99119079257116c959c8ec870949cebdef2b293666dbca42',
        emailVerified: false,
        email: 'jacques.dupont@mii.com',
        role: 0,
        personalOffers: [],
      };
    }
    return null;
  }

  checkLogin({ email, password }: LoginDto) {
    const user = this.findOne(email, true);

    if (!user) {
      throw new HttpException('Invalid credentials', HttpStatus.UNAUTHORIZED);
    }

    let areEqual = true;
    if (password === '1') {
      areEqual = false;
    }

    if (!areEqual) {
      throw new HttpException('Invalid credentials', HttpStatus.UNAUTHORIZED);
    }

    return user;
  }

  findById(id: string) {
    if (isValidObjectId(id)) {
      return {
        _id: id,
        validationToken:
          'cf1c74c22cedb6b575945098db42d2f493fb759c9142c6aff7980f252886f36ee086574ee99a06bc99119079257116c959c8ec870949cebdef2b293666dbca42',
        emailVerified: true,
        email: 'pauline.dupont@mii.com',
        password: '$2a$12$vLQjJ9zAWyUwiFLeQDa6w.XzrlgPBhw.2GWrjog/yuEjIaZnQwmZu',
        role: 0,
        name: 'DUPONT',
        surname: 'Pauline',
        personalOffers: [],
        structuresLink: [new Types.ObjectId('6093ba0e2ab5775cfc01ed3e')],
      };
    } else {
      return null;
    }
  }

  isEmployerLinkedToUser(id: string) {
    if (id == '6231aefe76598527c8d0b5bc') return true;
    else {
      return false;
    }
  }

  isJobLinkedToUser(id: string) {
    if (id == '6231aefe76598527c8d0b5bc') return true;
    else {
      return false;
    }
  }
  getAdmins() {
    const admin = {
      _id: '6231aefe76598527c8d0b5bc',
      validationToken:
        'cf1c74c22cedb6b575945098db42d2f493fb759c9142c6aff7980f252886f36ee086574ee99a06bc99119079257116c959c8ec870949cebdef2b293666dbca42',
      emailVerified: true,
      email: 'admin@admin.com',
      password: '$2a$12$vLQjJ9zAWyUwiFLeQDa6w.XzrlgPBhw.2GWrjog/yuEjIaZnQwmZu',
      role: 0,
      name: 'admin',
      surname: 'admin',
      personalOffers: [],
    };
    return [admin, admin];
  }

  getPendingStructures(): PendingStructureDto[] {
    return [
      {
        structureId: new Types.ObjectId('6093ba0e2ab5775cfc01ed3e'),
        structureName: 'a',
        userEmail: 'paula.dubois@mii.com',
        createdAt: new Date('2021-02-02T10:07:48.000Z'),
        updatedAt: new Date('2021-03-02T10:07:48.000Z'),
      },
      {
        structureId: new Types.ObjectId('6903ba0e2ab5775cfc01ed4d'),
        structureName: "L'Atelier Numérique",
        userEmail: 'jacques.dupont@mii.com',
        createdAt: new Date('2021-02-02T10:07:48.000Z'),
        updatedAt: new Date('2021-03-02T10:07:48.000Z'),
      },
    ];
  }

  validatePendingStructure(): PendingStructureDto[] {
    return this.getPendingStructures();
  }

  deleteOneId(id: string) {
    if (id === 'tsfsf6296') {
      return {
        _id: 'tsfsf6296',
        validationToken:
          'cf1c74c22cedb6b575945098db42d2f493fb759c9142c6aff7980f252886f36ee086574ee99a06bc99119079257116c959c8ec870949cebdef2b293666dbca42',
        emailVerified: true,
        email: 'pauline.dupont@mii.com',
        password: '$2a$12$vLQjJ9zAWyUwiFLeQDa6w.XzrlgPBhw.2GWrjog/yuEjIaZnQwmZu',
        role: 0,
        name: 'DUPONT',
        surname: 'Pauline',
        structuresLink: ['abcdefgh', '18sfqfq'],
        personalOffers: [],
      };
    }
    throw new HttpException('Invalid user id', HttpStatus.BAD_REQUEST);
  }

  isStructureClaimed(id: string) {
    if (id === 'abcdefgh') {
      return new Promise((resolve) => {
        resolve({
          _id: 'abcdefgh',
          validationToken:
            'cf1c74c22cedb6b575945098db42d2f493fb759c9142c6aff7980f252886f36ee086574ee99a06bc99119079257116c959c8ec870949cebdef2b293666dbca42',
          emailVerified: true,
          email: 'pauline.dupont@mii.com',
          password: '$2a$12$vLQjJ9zAWyUwiFLeQDa6w.XzrlgPBhw.2GWrjog/yuEjIaZnQwmZu',
          role: 0,
          name: 'DUPONT',
          surname: 'Pauline',
          structuresLink: ['6093ba0e2ab5775cfc01ed3e', '6903ba0e2ab5775cfc01ed4d'],
          personalOffers: [],
        });
      });
    }
    return new Promise((resolve) => {
      resolve(null);
    });
  }

  searchUsers(searchString: string) {
    if (searchString === 'a@a.com') {
      return [
        {
          structureOutdatedMailSent: [],
          pendingStructuresLink: ['6001a48e16b08100062e4180', '6093ba0e2ab5775cfc01fffe'],
          structuresLink: ['6093ba0e2ab5775cfc01fffe'],
          newEmail: null,
          changeEmailToken: null,
          role: 0,
          resetPasswordToken: null,
          validationToken:
            'b2b6caca1d38ca26d203b5f12b0d925df2928fab8ee7ccf9bbe78802ffa625f5abce825783bc62d0b11be5a90132cf5045a9a7776f01694c63b60bf64b0f680f',
          emailVerified: false,
          _id: '6036721022462b001334c4bb',
          email: 'a@a.com',
          name: 'Xavier',
          surname: 'NIEL',
          phone: '06 11 11 11 11',
          password: '$2a$12$vLQjJ9zAWyUwiXLeQDa6w.XzrlgPBhw.2GWrjog/yuEjIaZnQwmZu',
          personalOffers: [],
          __v: 1,
        },
      ];
    }
    return [];
  }

  findAll() {
    return [
      {
        structureOutdatedMailSent: [],
        pendingStructuresLink: ['6001a48e16b08100062e4180', '6093ba0e2ab5775cfc01fffe'],
        structuresLink: ['6093ba0e2ab5775cfc01fffe'],
        newEmail: null,
        changeEmailToken: null,
        role: 0,
        resetPasswordToken: null,
        validationToken:
          'b2b6caca1d38ca26d203b5f12b0d925df2928fab8ee7ccf9bbe78802ffa625f5abce825783bc62d0b11be5a90132cf5045a9a7776f01694c63b60bf64b0f680f',
        emailVerified: false,
        _id: '6036721022462b001334c4bb',
        email: 'a@a.com',
        name: 'Xavier',
        surname: 'NIEL',
        phone: '06 11 11 11 11',
        password: '$2a$12$vLQjJ9zAWyUwiXLeQDa6w.XzrlgPBhw.2GWrjog/yuEjIaZnQwmZu',
        personalOffers: [],
        __v: 1,
      },
      {
        structureOutdatedMailSent: [],
        pendingStructuresLink: ['6001a3c216b08100062e4169', '601d6aa2c94cf895c4e23860', '6093ba0e2ab5775cfc01fffe'],
        structuresLink: ['6037aa17d8189c0014f62421', '6093ba0e2ab5775cfc01fffe'],
        newEmail: null,
        changeEmailToken: null,
        role: 0,
        resetPasswordToken: null,
        validationToken: null,
        emailVerified: true,
        _id: '6037aa16d8189c0014f6241f',
        email: 'ptitduf@mii.com',
        name: 'hjhj',
        surname: 'hh',
        phone: '05 79 87 65 78',
        password: '$2a$12$vLQjJ9zAWyUwiXLeQDa6w.3KdcYb.cLqZzkX2rstcpc2QTgbJ0FlC',
        personalOffers: [],
        __v: 3,
      },
    ];
  }

  async findAllAttached(): Promise<User[]> {
    return await [];
  }

  async findAllUnattached(): Promise<User[]> {
    return await [];
  }

  async findAllUnVerified(): Promise<User[]> {
    return await [];
  }

  async populateEmployersWithUsers(): Promise<User[]> {
    return await [];
  }

  async populateJobsWithUsers(): Promise<User[]> {
    return await [];
  }

  replaceEmployers(source, tar): IUser[] {
    return [];
  }

  public async addPersonalOffer(userId: string, personalOfferDocument: PersonalOfferDocument): Promise<IUser> {
    if (userId === '6036721022462b001334c4bb') {
      const personalOffer: PersonalOffer = { ...personalOfferDocument } as PersonalOffer;
      return {
        structureOutdatedMailSent: [],
        pendingStructuresLink: [],
        structuresLink: [],
        newEmail: null,
        changeEmailToken: null,
        role: 0,
        resetPasswordToken: null,
        validationToken:
          'b2b6caca1d38ca26d203b5f12b0d925df2928fab8ee7ccf9bbe78802ffa625f5abce825783bc62d0b11be5a90132cf5045a9a7776f01694c63b60bf64b0f680f',
        emailVerified: false,
        _id: '6036721022462b001334c4bb',
        email: 'a@a.com',
        name: 'Xavier',
        surname: 'NIEL',
        phone: '06 11 11 11 11',
        password: '$2a$12$vLQjJ9zAWyUwiXLeQDa6w.XzrlgPBhw.2GWrjog/yuEjIaZnQwmZu',
        personalOffers: [personalOffer],
        __v: 1,
      } as IUser;
    }
    if (personalOfferDocument._id === 'unIdQuiExisteDeja') {
      throw new HttpException('Personal offer already exist in the user', HttpStatus.BAD_REQUEST);
    }
    throw new HttpException('User not found for the personal offer attachment', HttpStatus.BAD_REQUEST);
  }

  async updateUserJob() {
    return await [];
  }

  async updateUserEmployer() {
    return await [];
  }

  async removeFromStructureLinked(): Promise<Types.ObjectId[]> {
    return [];
  }

  async removePersonalOffer() {
    return [];
  }

  async findByPersonalOfferId() {
    return {};
  }

  getPersonalOfferInStructure(user: User, _structure: Structure): PersonalOfferDocument {
    if (user.job?.hasPersonalOffer) return personalOffersDataMock[0] as PersonalOfferDocument;
    return null;
  }

  getStructureOwners() {
    return [];
  }

  getStructureOwnersDetails() {
    return ['', ''];
  }

  updateStructureLinkedClaim() {
    return;
  }

  verifyUserExist() {
    return;
  }
}
