import { Db } from 'mongodb';
import { getDb } from '../migrations-utils/db';

export const up = async () => {
  try {
    const db: Db = await getDb();
    await db.collection('structures').updateMany({}, { $unset: { lockdownActivity: '' } });
    await db.collection('parameters').drop();
    console.log(`Update done: removed 'lockdownActivity' from 'structures' and deleted the 'parameters' collection`);
  } catch (error) {
    console.error('Error dropping lockdownActivity:', error);
  }
};

export const down = async () => {
  try {
    const db: Db = await getDb();
    const updateResult = await db.collection('structures').updateMany({}, { $set: { lockdownActivity: '' } });
    await db
      .collection('parameters')
      .insertOne({ lockdownInfoDisplay: false, createdAt: new Date(), updatedAt: new Date() });
    console.log(
      `Downgrade done: added lockdownActivity to ${updateResult.modifiedCount} structures and added the 'parameters' collection back with its contents`
    );
  } catch (error) {
    console.error('Error restoring a lockdownActivity collection:', error);
  }
};
